@@ -102,6 +102,7 @@ var stdsoap2_8h =
     [ "SOAP_MAXARRAYSIZE", "group__group__soap.html#ga29a7dab5c96c2724b3c234505d52c76e", null ],
     [ "SOAP_MAXDIMESIZE", "group__group__soap.html#gad4c2ca8c2293fc75075aec4a09f4dc38", null ],
     [ "SOAP_MAXEINTR", "group__group__soap.html#ga59f0c79e1cd2a135f74351bf9f8c17a6", null ],
+    [ "SOAP_MAXHTTPCHUNK", "group__group__soap.html#gadf06a04f79f46d6c32b4c960e112bdfb", null ],
     [ "SOAP_MAXINFLATESIZE", "group__group__soap.html#ga449296b6ea91c469c16ed505f04ca070", null ],
     [ "SOAP_MAXKEEPALIVE", "group__group__soap.html#ga9750ea0479df8aa88e06f6a148b2a670", null ],
     [ "SOAP_MAXLENGTH", "group__group__soap.html#gabd0dd334a752d8c145fa720deb905508", null ],
@@ -159,6 +160,7 @@ var stdsoap2_8h =
     [ "SOAP_SSL_RSA", "group__group__ssl.html#gab7153fa5dcada365bce84add0cb60a8e", null ],
     [ "SOAP_SSL_RSA_BITS", "group__group__soap.html#gab18ff4d6039f1387641508ae7be8a145", null ],
     [ "SOAP_SSL_SKIP_HOST_CHECK", "group__group__ssl.html#ga2d7d44f0b65da9941f0272b0f73745f5", null ],
+    [ "SOAP_SSL_SNI_HOST_CHECK", "group__group__ssl.html#ga7f09d0dfe73b2dbeb04f4fc38a600002", null ],
     [ "SOAP_SSLv3", "group__group__ssl.html#ga0d4dc7f02c689dd69a5508848b7b701d", null ],
     [ "SOAP_SSLv3_TLSv1", "group__group__ssl.html#gaf273a14b5105e943a0280947d7def8ff", null ],
     [ "SOAP_STD_EXPORTS", "group__group__soap.html#ga3176b06a7c108fc79cb2319a9e2f6fd2", null ],
@@ -239,6 +241,7 @@ var stdsoap2_8h =
     [ "WITH_NOZONE", "group__group__with.html#ga1c6f7ec29799a308133930ffc4d7109a", null ],
     [ "WITH_NTLM", "group__group__with.html#ga4a743d1499292194cfc81d305500c83f", null ],
     [ "WITH_OPENSSL", "group__group__with.html#gae5fa06f0e13edb611016c85364b0d0f0", null ],
+    [ "WITH_POSIX_STRERROR_R", "group__group__with.html#gad8bdadc081864241d90a266beb7f2d9a", null ],
     [ "WITH_PURE_VIRTUAL", "group__group__with.html#gaa0801009d3ed28b2c66063c26423fa8d", null ],
     [ "WITH_REPLACE_ILLEGAL_UTF8", "group__group__with.html#gaa3632d9a171ac29a7cb4a4c4861d8e8d", null ],
     [ "WITH_SELF_PIPE", "group__group__with.html#ga0f1f2dd7a7d88f5acdaaab010d8e99ff", null ],
@@ -246,6 +249,7 @@ var stdsoap2_8h =
     [ "WITH_SOCKET_CLOSE_ON_EXIT", "group__group__with.html#ga11ff99091a8f7fa179705bb3bff1aed2", null ],
     [ "WITH_SSL_FULL_SHUTDOWN", "group__group__with.html#ga861b3552cdade3f062b0caa2e187746f", null ],
     [ "WITH_TCPFIN", "group__group__with.html#ga32da1a1af344a155b0ad01e6dbb7daaa", null ],
+    [ "WITH_WOLFSSL", "group__group__with.html#gad10abbdcee2595b6ad21dbf595d7ca8c", null ],
     [ "WITH_ZLIB", "group__group__with.html#gad2cdc1f87f3fc46b92e957d9e251797c", null ],
     [ "_QName", "group__group__context.html#gaa178a46d0cf703ff226a5c148483286d", null ],
     [ "_XML", "group__group__context.html#ga5c62d26b4823b76c5b4ef29e7865d3f0", null ],
